@@ -36,34 +36,39 @@ class EmptyStartEventHandler(NodeHandler):
         :return: 执行结果
         :rtype: ExecuteResult
         """
-        top_pipeline_id = process_info.top_pipeline_id
-        root_pipeline_inputs = self._get_plain_inputs(process_info.root_pipeline_id)
 
-        need_pre_render = True
         try:
             data = self.runtime.get_data(self.node.id)
         except NotFoundError:
             need_pre_render = False
+        else:
+            need_pre_render = True
 
         if need_pre_render:
+            top_pipeline_id = process_info.top_pipeline_id
+            root_pipeline_inputs = self._get_plain_inputs(process_info.root_pipeline_id)
             upsert_context_dict = dict()
             pre_render_keys = data.inputs["pre_render_keys"].value
 
             logger.info("{} pre_render_keys are: {}".format(top_pipeline_id, ",".join(pre_render_keys)))
 
+            refs = self.runtime.get_context_key_references(pipeline_id=top_pipeline_id, keys=set(pre_render_keys))
+
             context_values = self.runtime.get_context_values(
-                pipeline_id=top_pipeline_id, keys=pre_render_keys
+                pipeline_id=top_pipeline_id, keys=set(pre_render_keys).union(refs)
             )
             context = Context(self.runtime, context_values, root_pipeline_inputs)
             hydrated_context = context.hydrate(deformat=False)
             for context_value in context_values:
                 context_key = context_value.key
-                if context_key in hydrated_context:
+                if context_key in pre_render_keys:
                     upsert_context_dict[context_key] = ContextValue(
                         key=context_key,
                         type=ContextValueType.PLAIN,
                         value=hydrated_context[context_key],
                     )
+
+            logger.info(f"{top_pipeline_id} pre_render_keys results are: {upsert_context_dict}")
             self.runtime.upsert_plain_context_values(top_pipeline_id, upsert_context_dict)
 
         self.runtime.set_state(
